"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PubSubClient = void 0;
const axios_1 = __importDefault(require("axios"));
const auth_js_1 = require("./auth.js");
const api_js_1 = require("../api.js");
const environments_js_1 = require("../configurations/environments.js");
const error_js_1 = require("./error.js");
class PubSubClient {
    constructor(config) {
        this.config = config;
        this.environmentConfig = environments_js_1.defaultEnvironmentConfig[this.config.environment];
        this.subscriptionsUrl = this.environmentConfig.apiBaseUrl + "/Subscriptions";
        this.publishUrl = this.environmentConfig.apiBaseUrl + "/Publish";
        this.auth = new auth_js_1.Auth({
            audience: this.environmentConfig.oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: config.scopes,
            tokenUrl: this.environmentConfig.tokenUrl,
            customOptions: config.customOptions
        });
        this.httpClient = axios_1.default.create({
            validateStatus: () => true
        });
    }
    async subscribe(data) {
        const url = this.subscriptionsUrl;
        const res = await this.httpClient.post(url, api_js_1.ObjectSerializer.serialize(data, "SubscribeRequestData"), {
            headers: await this.auth.getHeaders(),
        });
        if (res.status === 200) {
            return api_js_1.ObjectSerializer.serialize(res.data, "SubscribeResponseData");
        }
        else {
            throw new error_js_1.PubSubError("Subscribing failed", res);
        }
    }
    async deleteSubscription(typeName, subscriptionId = "") {
        const queryString = subscriptionId ?
            "?subscriptionId=" + encodeURIComponent(subscriptionId) :
            "";
        const url = `${this.subscriptionsUrl}/${typeName}${queryString}`;
        const res = await this.httpClient.delete(url, {
            headers: await this.auth.getHeaders(),
        });
        if (res.status === 200) {
            return api_js_1.ObjectSerializer.serialize(res.data, "SubscribeResponseData");
        }
        else {
            throw new error_js_1.PubSubError("Deleting subscription failed", res);
        }
    }
    async publish(data) {
        const url = this.publishUrl;
        const res = await this.httpClient.post(url, api_js_1.ObjectSerializer.serialize(data, "PublishRequestData"), {
            headers: await this.auth.getHeaders(),
        });
        if (res.status !== 200) {
            throw new error_js_1.PubSubError("Publishing failed", res);
        }
    }
}
exports.PubSubClient = PubSubClient;
