import axios from "axios";
import { Auth } from "./auth.js";
import { ObjectSerializer } from "../api.js";
import { defaultEnvironmentConfig } from "../configurations/environments.js";
import { PubSubError } from "./error.js";
export class PubSubClient {
    constructor(config) {
        this.config = config;
        this.environmentConfig = defaultEnvironmentConfig[this.config.environment];
        this.subscriptionsUrl = this.environmentConfig.apiBaseUrl + "/Subscriptions";
        this.publishUrl = this.environmentConfig.apiBaseUrl + "/Publish";
        this.auth = new Auth({
            audience: this.environmentConfig.oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: config.scopes,
            tokenUrl: this.environmentConfig.tokenUrl,
            customOptions: config.customOptions
        });
        this.httpClient = axios.create({
            validateStatus: () => true
        });
    }
    async subscribe(data) {
        const url = this.subscriptionsUrl;
        const res = await this.httpClient.post(url, ObjectSerializer.serialize(data, "SubscribeRequestData"), {
            headers: await this.auth.getHeaders(),
        });
        if (res.status === 200) {
            return ObjectSerializer.serialize(res.data, "SubscribeResponseData");
        }
        else {
            throw new PubSubError("Subscribing failed", res);
        }
    }
    async deleteSubscription(typeName, subscriptionId = "") {
        const queryString = subscriptionId ?
            "?subscriptionId=" + encodeURIComponent(subscriptionId) :
            "";
        const url = `${this.subscriptionsUrl}/${typeName}${queryString}`;
        const res = await this.httpClient.delete(url, {
            headers: await this.auth.getHeaders(),
        });
        if (res.status === 200) {
            return ObjectSerializer.serialize(res.data, "SubscribeResponseData");
        }
        else {
            throw new PubSubError("Deleting subscription failed", res);
        }
    }
    async publish(data) {
        const url = this.publishUrl;
        const res = await this.httpClient.post(url, ObjectSerializer.serialize(data, "PublishRequestData"), {
            headers: await this.auth.getHeaders(),
        });
        if (res.status !== 200) {
            throw new PubSubError("Publishing failed", res);
        }
    }
}
